Rename library and update build system

Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/tlv.hpp b/src/tlv.hpp
index 26444ac..6aae9a1 100644
--- a/src/tlv.hpp
+++ b/src/tlv.hpp
@@ -1,29 +1,27 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /**
 * Copyright (c) 2013-2014 Regents of the University of California.
 *
 * This file is part of ndn-cxx library (NDN C++ library with eXperimental eXtensions).
 *
 * ndn-cxx library is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * ndn-cxx library is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU General Public License and GNU Lesser
 * General Public License along with ndn-cxx, e.g., in COPYING.md file.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * See AUTHORS.md for complete list of ndn-cxx authors and contributors.
 */
 
-#ifndef NDN_GEP_TLV_HPP
-#define NDN_GEP_TLV_HPP
+#ifndef NDN_NAC_TLV_HPP
+#define NDN_NAC_TLV_HPP
 
 namespace ndn {
-namespace gep {
+namespace nac {
 namespace tlv {
 
 enum {
@@ -55,7 +53,7 @@
 };
 
 } // namespace tlv
-} // namespace gep
+} // namespace nac
 } // namespace ndn
 
-#endif // NDN_GEP_TLV_HPP
+#endif // NDN_NAC_TLV_HPP
@@ -1,29 +1,27 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /**
-* Copyright (c) 2013-2014 Regents of the University of California.
-*
-* This file is part of ndn-cxx library (NDN C++ library with eXperimental eXtensions).
-*
-* ndn-cxx library is free software: you can redistribute it and/or modify it under the
-* terms of the GNU Lesser General Public License as published by the Free Software
-* Foundation, either version 3 of the License, or (at your option) any later version.
-*
-* ndn-cxx library is distributed in the hope that it will be useful, but WITHOUT ANY
-* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-* PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
-*
-* You should have received copies of the GNU General Public License and GNU Lesser
-* General Public License along with ndn-cxx, e.g., in COPYING.md file.  If not, see
-* <http://www.gnu.org/licenses/>.
-*
-* See AUTHORS.md for complete list of ndn-cxx authors and contributors.
-*/
+ * Copyright (c) 2014-2018, Regents of the University of California
+ *
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
+ *
+ * NAC is free software: you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software Foundation,
+ * either version 3 of the License, or (at your option) any later version.
+ *
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * NAC, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
+ */
 